@@ -1,5 +1,5 @@
 /* ************************************************************************
-* Copyright (C) 2022-2023 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2022-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -49,17 +49,9 @@ void testing_spitsv_csr_bad_arg(const Arguments& arg)
     rocsparse_local_handle local_handle;
 
     // Spitsv structures
-    rocsparse_local_spmat local_A(m,
-                                  n,
-                                  nnz,
-                                  (void*)0x4,
-                                  (void*)0x4,
-                                  (void*)0x4,
-                                  itype,
-                                  jtype,
-                                  base,
-                                  compute_type,
-                                  rocsparse_format_csr);
+    rocsparse_local_spmat local_A(
+        m, n, nnz, (void*)0x4, (void*)0x4, (void*)0x4, itype, jtype, base, compute_type);
+
     rocsparse_local_dnvec local_x(m, (void*)0x4, compute_type);
     rocsparse_local_dnvec local_y(m, (void*)0x4, compute_type);
 
@@ -197,17 +189,9 @@ void testing_spitsv_csr(const Arguments& arg)
     CHECK_HIP_ERROR(hipMemcpy(dalpha, &halpha, sizeof(T), hipMemcpyHostToDevice));
 
     // Create descriptors
-    rocsparse_local_spmat A(M,
-                            N,
-                            nnz_A,
-                            dcsr_row_ptr,
-                            dcsr_col_ind,
-                            dcsr_val,
-                            itype,
-                            jtype,
-                            base,
-                            ttype,
-                            rocsparse_format_csr);
+    rocsparse_local_spmat A(
+        M, N, nnz_A, dcsr_row_ptr, dcsr_col_ind, dcsr_val, itype, jtype, base, ttype);
+
     rocsparse_local_dnvec x(M, dx, ttype);
     rocsparse_local_dnvec y1(M, dy_1, ttype);
     rocsparse_local_dnvec y2(M, dy_2, ttype);
@@ -331,6 +315,7 @@ void testing_spitsv_csr(const Arguments& arg)
                             hcsr_col_ind,
                             hcsr_val,
                             hx,
+                            (int64_t)1,
                             hy_gold,
                             diag,
                             uplo,
@@ -340,6 +325,11 @@ void testing_spitsv_csr(const Arguments& arg)
 
         if(analysis_pivot == -1 && solve_pivot == -1)
         {
+            if(ROCSPARSE_REPRODUCIBILITY)
+            {
+                rocsparse_reproducibility::save(
+                    "Y pointe mode host", hy_1, "Y pointe mode device", hy_2);
+            }
             hy_gold.near_check(hy_1);
             hy_gold.near_check(hy_2);
         }
