@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -207,6 +207,22 @@ typedef struct _rocsparse_dnmat_descr const* rocsparse_const_dnmat_descr;
  */
 typedef struct _rocsparse_color_info* rocsparse_color_info;
 
+/*! \ingroup types_module
+ * \brief rocsparse_sparse_to_sparse_descr is a structure holding the rocsparse sparse_to_sparse
+ * descr data. It must be initialized using
+ * the rocsparse_create_sparse_to_sparse_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_sparse_to_sparse_descr().
+ */
+typedef struct _rocsparse_sparse_to_sparse_descr* rocsparse_sparse_to_sparse_descr;
+
+/*! \ingroup types_module
+ * \brief rocsparse_extract_descr is a structure holding the rocsparse extract
+ * descr data. It must be initialized using
+ * the rocsparse_create_extract_descr() routine. It should be destroyed at the
+ * end using rocsparse_destroy_extract_descr().
+ */
+typedef struct _rocsparse_extract_descr* rocsparse_extract_descr;
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -543,6 +559,30 @@ typedef enum rocsparse_sparse_to_sparse_stage_
     rocsparse_sparse_to_sparse_stage_compute  = 1 /**< Performs the actual conversion. */
 } rocsparse_sparse_to_sparse_stage;
 
+/*! \ingroup types_module
+   *  \brief List of extract algorithms.
+   *
+   *  \details
+   *  This is a list of supported \ref rocsparse_extract_alg types that are used to perform
+   *  the submatrix extraction.
+   */
+typedef enum rocsparse_extract_alg_
+{
+    rocsparse_extract_alg_default = 0, /**< Default extract algorithm for the given format. */
+} rocsparse_extract_alg;
+
+/*! \ingroup types_module
+   *  \brief List of extract stages.
+   *
+   *  \details
+   *  The analysis \ref rocsparse_extract_stage_analysis must be done before the first call of the calculation \ref rocsparse_extract_stage_compute.
+   */
+typedef enum rocsparse_extract_stage_
+{
+    rocsparse_extract_stage_analysis = 0, /**< Data analysis. */
+    rocsparse_extract_stage_compute  = 1 /**< Performs the actual extraction. */
+} rocsparse_extract_stage;
+
 /*! \ingroup types_module
  *  \brief List of Iterative ILU0 algorithms.
  *
@@ -737,10 +777,13 @@ typedef enum rocsparse_spmm_alg_
     rocsparse_spmm_alg_coo_segmented, /**< SpMM algorithm for COO format using segmented scan. */
     rocsparse_spmm_alg_coo_atomic, /**< SpMM algorithm for COO format using atomics. */
     rocsparse_spmm_alg_csr_row_split, /**< SpMM algorithm for CSR format using row split and shfl. */
-    rocsparse_spmm_alg_csr_merge, /**< SpMM algorithm for CSR format using conversion to COO. */
+    rocsparse_spmm_alg_csr_merge, /**< SpMM algorithm for CSR format using nnz split algorithm. Is the same as rocsparse_spmm_alg_csr_nnz_split. */
     rocsparse_spmm_alg_coo_segmented_atomic, /**< SpMM algorithm for COO format using segmented scan and atomics. */
     rocsparse_spmm_alg_bell, /**< SpMM algorithm for Blocked ELL format. */
-    rocsparse_spmm_alg_bsr /**< SpMM algorithm for BSR format. */
+    rocsparse_spmm_alg_bsr, /**< SpMM algorithm for BSR format. */
+    rocsparse_spmm_alg_csr_merge_path, /**< SpMM algorithm for CSR format using merge path algorithm. */
+    rocsparse_spmm_alg_csr_nnz_split
+    = rocsparse_spmm_alg_csr_merge /**< SpMM algorithm for CSR format using nnz split algorithm. */
 } rocsparse_spmm_alg;
 
 /*! \ingroup types_module
